==> racer-0.1.1.tgz: package/lib/racer.js <==
var DEFAULT_TRANSPORTS, Model, Store, browserify, ioClient, session, socketio, uglify, util;
Model = require('./Model.server');
Store = require('./Store');
socketio = require('socket.io');
ioClient = require('socket.io-client');
browserify = require('browserify');
uglify = require('uglify-js');
util = require('./util');
session = require('./session');
DEFAULT_TRANSPORTS = ['websocket', 'xhr-polling'];
Store.prototype.setSockets = function(sockets, ioUri) {
  this.sockets = sockets;
  if (ioUri == null) {
    ioUri = '';
  }
  this._setSockets(this.sockets);
  return this._ioUri = ioUri;
};
Store.prototype.listen = function(to, namespace) {
  var io, socketUri;
  io = socketio.listen(to);
  io.configure(function() {
    io.set('browser client', false);
    return io.set('transports', DEFAULT_TRANSPORTS);
  });
  io.configure('production', function() {
    return io.set('log level', 1);
  });
  socketUri = typeof to === 'number' ? ':' + to : '';
  if (namespace) {
    return this.setSockets(io.of("/" + namespace), "" + socketUri + "/" + namespace);
  } else {
    return this.setSockets(io.sockets, socketUri);
  }
};
module.exports = {
  createStore: function(options) {
    var store;
    store = new Store(options);
    if (options.sockets) {
      store.setSockets(options.sockets, options.socketUri);
    } else if (options.listen) {
      store.listen(options.listen, options.namespace);
    }
    return store;
  },
  js: function(options, callback) {
    var minify, _ref;
    if (typeof options === 'function') {
      _ref = [options, {}], callback = _ref[0], options = _ref[1];
    }
    if ((minify = options.minify) === void 0) {
      minify = true;
    }
    if (minify) {
      options.filter = uglify;
    }
    return ioClient.builder(DEFAULT_TRANSPORTS, {
      minify: minify
    }, function(err, value) {
      if (err) {
        throw err;
      }
      return callback(value + ';' + browserify.bundle(options));
    });
  },
  util: util,
  Model: Model,
  session: session
};

==> racer-0.1.3.tgz: package/lib/racer.js <==
var DEFAULT_TRANSPORTS, Model, Store, browserify, ioClient, racer, session, socketio, uglify, util;

Model = require('./Model.server');

Store = require('./Store');

socketio = require('socket.io');

ioClient = require('socket.io-client');

browserify = require('browserify');

uglify = require('uglify-js');

util = require('./util');

session = require('./session');

DEFAULT_TRANSPORTS = ['websocket', 'xhr-polling'];

Store.prototype.setSockets = function(sockets, ioUri) {
  this.sockets = sockets;
  if (ioUri == null) ioUri = '';
  this._setSockets(this.sockets);
  return this._ioUri = ioUri;
};

Store.prototype.listen = function(to, namespace) {
  var io, socketUri;
  io = socketio.listen(to);
  io.configure(function() {
    io.set('browser client', false);
    return io.set('transports', DEFAULT_TRANSPORTS);
  });
  io.configure('production', function() {
    return io.set('log level', 1);
  });
  socketUri = typeof to === 'number' ? ':' + to : '';
  if (namespace) {
    return this.setSockets(io.of("/" + namespace), "" + socketUri + "/" + namespace);
  } else {
    return this.setSockets(io.sockets, socketUri);
  }
};

racer = module.exports = {
  createStore: function(options) {
    var store;
    store = new Store(options);
    if (options.sockets) {
      store.setSockets(options.sockets, options.socketUri);
    } else if (options.listen) {
      store.listen(options.listen, options.namespace);
    }
    return store;
  },
  js: function(options, callback) {
    var minify, _ref;
    if (typeof options === 'function') {
      _ref = [options, {}], callback = _ref[0], options = _ref[1];
    }
    if ((minify = options.minify) === void 0) minify = true;
    if (minify) options.filter = uglify;
    return ioClient.builder(DEFAULT_TRANSPORTS, {
      minify: minify
    }, function(err, value) {
      if (err) throw err;
      return callback(value + ';' + browserify.bundle(options));
    });
  },
  util: util,
  Model: Model,
  session: session
};

Object.defineProperty(racer, 'version', {
  get: function() {
    return JSON.parse(fs.readFileSync(__dirname + '/../package.json', 'utf8')).version;
  }
});
